==> scholar_network-0.1.0-py3-none-any.whl: scholar_network/helpers.py <==
from typing import Union
from . import models
import json
import networkx as nx
import pickle

ENCODING = "utf-8-sig"

# TODO: add functionality to compare authors/coauthor list and check
# string similarity to avoid duplicate authors
# --> probably build the name standardization package and use here


def load_scholars_json():
    with open("data/flattened-scraped.json", "r", encoding=ENCODING) as f:
        scholars = json.load(f)
    return scholars


def build_graph(
    author1: Union[str, None] = None, author2: Union[str, None] = None
) -> models.Graph:
    publications = load_scholars_json()
    graph = models.Graph()
    for pub in publications:
        co_authors = set([c.strip() for c in pub.get("authors").split(",")])

        if not author1 and not author2:  # make whole graph
            for co in co_authors:
                graph.add_node(models.Node(co))
                for other in co_authors:
                    graph.add_node(models.Node(co))
                    for other in co_authors:
                        if other == co:
                            continue
                        graph.add_node(models.Node(other))
                        graph.add_edge(
                            models.Edge(graph.get_node(co), graph.get_node(other))
                        )

        # otherwise at least one author passed
        # if author in coauthors set then add that network
        if author1 in co_authors or author2 in co_authors:
            for co in co_authors:
                graph.add_node(models.Node(co))
                for other in co_authors:
                    graph.add_node(models.Node(co))
                    for other in co_authors:
                        if other == co:
                            continue
                        graph.add_node(models.Node(other))
                        graph.add_edge(
                            models.Edge(graph.get_node(co), graph.get_node(other))
                        )

        # TODO: add support for journal title as attribute of edge
        # TODO: want weight to track number of connections on each edge
        # TODO: look at speed enhancements
        # journal = scholars[name].get("journal_title").strip()

    return graph


def save_graph(connections: list[tuple[str, str]]):
    G = nx.Graph()
    G.add_edges_from(connections)
    positions = nx.spring_layout(G)
    with open("data/COP-graph.pkl", "wb") as f:
        pickle.dump(G, f)
    with open("data/COP-graph-positions.pkl", "wb") as f:
        pickle.dump(positions, f)
    return


def load_graph_from_files() -> tuple[nx.Graph, nx.layout.spring_layout]:
    with open("data/COP-graph.pkl", "rb") as f:
        g = pickle.load(f)
    with open("data/COP-graph-positions.pkl", "rb") as f:
        positions = pickle.load(f)
    return g, positions

==> scholar_network-0.1.2-py3-none-any.whl: scholar_network/helpers.py <==
import json
from typing import Union

from . import models

ENCODING = "utf-8-sig"


def load_publications():
    with open("data/scraped.json", "r", encoding=ENCODING) as f:
        scholars = json.load(f)
    return scholars


def append_pub_data_to_json(publication_info: list[dict[str, str]]):
    with open("data/scraped.json", "r", encoding=ENCODING) as f:
        data = json.load(f)
    data.append(publication_info)
    with open("data/scraped.json", "w", encoding=ENCODING) as f:
        json.dump(data, f, indent=4, sort_keys=True)


def build_graph(
    author1: Union[str, None] = None, author2: Union[str, None] = None
) -> models.Graph:
    publications = load_publications()
    graph = models.Graph()
    for pub in publications:
        co_authors = set([c.strip() for c in pub.get("authors").split(",")])

        if not author1 and not author2:  # make whole graph
            for co in co_authors:
                graph.add_node(models.Node(co))
                for other in co_authors:
                    graph.add_node(models.Node(co))
                    for other in co_authors:
                        if other == co:
                            continue
                        graph.add_node(models.Node(other))
                        graph.add_edge(
                            models.Edge(graph.get_node(co), graph.get_node(other))
                        )

        # otherwise at least one author passed
        # if author in coauthors set then add that network
        if author1 in co_authors or author2 in co_authors:
            for co in co_authors:
                graph.add_node(models.Node(co))
                for other in co_authors:
                    if other == co:
                        continue
                    graph.add_node(models.Node(other))
                    graph.add_edge(
                        models.Edge(graph.get_node(co), graph.get_node(other))
                    )

        # TODO: add support for journal title as attribute of edge
        # TODO: want weight to track number of connections on each edge
        # TODO: look at speed enhancements
        # journal = scholars[name].get("journal_title").strip()
    return graph
